==> codemirror-lang-tasl-0.1.1.tgz: package/lib/index.js <==
import { continuedIndent, indentNodeProp, foldNodeProp, LRLanguage, } from "@codemirror/language";
import { styleTags, tags } from "@codemirror/highlight";
import { parser } from "lezer-tasl";
const styleNodeProp = styleTags({
    Comment: tags.string,
    "ClassDeclaration/Term": [tags.className, tags.strong],
    "NamespaceDefinition/Identifier": tags.name,
    "NamespaceDefinition/NamespaceURI": [tags.url, tags.link],
    Identifier: tags.typeName,
    URI: tags.atom,
    "Literal/Datatype": tags.operator,
    "Literal/Term": tags.string,
    "OpenBrace CloseBrace": tags.brace,
    "OpenBracket CloseBracket": tags.bracket,
    "Component/Term Option/Term": tags.propertyName,
    "Reference/Pointer": tags.operator,
    "Reference/Term": [tags.className, tags.strong],
    "RightArrow LeftArrow": tags.separator,
    "namespace type class": tags.keyword,
});
export const taslLanguage = LRLanguage.define({
    parser: parser.configure({
        props: [
            indentNodeProp.add({
                Product: continuedIndent({ except: /^\s*\}/ }),
                Coproduct: continuedIndent({ except: /^\s*\]/ }),
            }),
            foldNodeProp.add({
                Product(subtree) {
                    return { from: subtree.from + 1, to: subtree.to - 1 };
                },
                Coproduct(subtree) {
                    return { from: subtree.from + 1, to: subtree.to - 1 };
                },
            }),
            styleNodeProp,
        ],
    }),
    languageData: {
        closeBrackets: { brackets: ["[", "{"] },
        indentOnInput: /^\s*[\}\]]$/,
        commentTokens: { line: "#" },
    },
});

==> codemirror-lang-tasl-0.1.3.tgz: package/lib/index.js <==
import { continuedIndent, indentNodeProp, foldNodeProp, LRLanguage, } from "@codemirror/language";
import { styleTags, tags } from "@codemirror/highlight";
import { parser } from "lezer-tasl";
const styleNodeProp = styleTags({
    Comment: tags.comment,
    "ClassDeclaration/Term": tags.className,
    "NamespaceDefinition/Identifier": tags.name,
    "NamespaceDefinition/NamespaceURI": [tags.url, tags.link],
    Identifier: tags.typeName,
    URI: tags.atom,
    "Literal/Datatype": tags.operator,
    "Literal/Term": tags.string,
    "OpenBrace CloseBrace": tags.brace,
    "OpenBracket CloseBracket": tags.bracket,
    "Component/Term Option/Term": tags.propertyName,
    "Reference/Pointer": tags.operator,
    "Reference/Term": tags.className,
    "RightArrow LeftArrow": tags.separator,
    "namespace type class": tags.keyword,
});
export const taslLanguage = LRLanguage.define({
    parser: parser.configure({
        props: [
            indentNodeProp.add({
                Product: continuedIndent({ except: /^\s*\}/ }),
                Coproduct: continuedIndent({ except: /^\s*\]/ }),
            }),
            foldNodeProp.add({
                Product(subtree) {
                    return { from: subtree.from + 1, to: subtree.to - 1 };
                },
                Coproduct(subtree) {
                    return { from: subtree.from + 1, to: subtree.to - 1 };
                },
            }),
            styleNodeProp,
        ],
    }),
    languageData: {
        closeBrackets: { brackets: ["[", "{"] },
        indentOnInput: /^\s*[\}\]]$/,
        commentTokens: { line: "#" },
    },
});
